==> mod_uploader-2.5.1.tgz: mod_uploader-2.5.1/util/WWW/SourceforgeJP.pm <==
package WWW::SourceforgeJP;

use strict;
use vars qw($VERSION);

$VERSION = 0.01;

use WWW::Mechanize;

use constant LIST_RELEASE_LABEL         => '꡼ե롦ꥹ';
use constant LIST_RELEASE_LINK_LABEL    => '꡼';
use constant EDIT_RELEASE_LABEL         => '꡼Խ';
use constant EDIT_RELEASE_LINK_LABEL    => 'ե꡼/ѹ';
use constant CREATE_RELEASE_LABEL       => '꡼ο';

sub new {
    my $class = shift;
    my $project = shift;

    my $member = {
        project => $project,
        mech => WWW::Mechanize->new(),
    };

    $member->{'mech'}->agent_alias('Windows IE 6');

    bless $member, $class;
}

sub login {
    my $self = shift;
    my $user = shift;
    my $pass = shift;

    $self->{'mech'}->get('https://sourceforge.jp/account/login.php');
    $self->{'mech'}->form_number(2);
    $self->{'mech'}->field('form_loginname', $user);
    $self->{'mech'}->field('form_pw', $pass);
    $self->{'mech'}->click();

    if ($self->{'mech'}->content() =~ /\QInvalid\E/) {
        die '˼Ԥޤ';
    }
}

sub create_release {
    my $self = shift;
    my $package = shift;
    my $version = shift;
    my $file_path = shift;
    my $file_name  = (split(/[\/\\]/, $file_path))[-1];
    my @links;


    @links = $self->get_release_links();

    if (grep($_->text() eq $file_name, @links)) {
        die 'Ʊ̾Υ꡼¸ߤޤ';
    }

    $self->_mv_create_release_page($package);

    $self->{'mech'}->form_number(2);
    $self->{'mech'}->field('release_name', $version);
    $self->{'mech'}->field('userfile', $file_path);
    $self->{'mech'}->click();

    @links = $self->get_release_links();

    unless (grep($_->text() eq $file_name, @links)) {
        die '꡼κ˼Ԥޤ';
    }
}

sub get_release_links {
    my $self = shift;
    my @links;

    $self->_mv_list_release_page();

    @links = grep($_->url() =~ m|\Qhttp://prdownloads.\E|,
                  $self->{'mech'}->find_all_links());

    map { $_->[0] }
        sort { $b->[1] <=> $a->[1] }
            map { [$_, ($_->text() =~ /([\d.]+)/)[0]] } @links;
}


sub _mv_list_release_page {
    my $self = shift;
    my $link;

    $self->{'mech'}->get("/projects/@{[$self->{'project'}]}/admin");

    $link = $self->{'mech'}->find_link(text => LIST_RELEASE_LINK_LABEL);
    $self->{'mech'}->get($link->url());

    if ($self->{'mech'}->content() !~ /\Q@{[LIST_RELEASE_LABEL]}[0]\E/) {
        die '꡼ΰڡؤΰư˼Ԥޤ';
    }
}

sub _mv_edit_release_page {
    my $self = shift;
    my $link;

    $self->{'mech'}->get("/projects/@{[$self->{'project'}]}/admin");
    $link = $self->{'mech'}->find_link(text => EDIT_RELEASE_LINK_LABEL);
    $self->{'mech'}->get($link->url());

    if ($self->{'mech'}->content() !~ /\Q@{[EDIT_RELEASE_LABEL]}[0]\E/) {
        die '꡼Խڡؤΰư˼Ԥޤ';
    }
}

sub _mv_create_release_page {
    my $self = shift;
    my $package = shift;
    my $link;
    my $url;

    $self->_mv_edit_release_page();
    $link = $self->{'mech'}->find_link(text => $package);

    if (! defined $link) {
        die 'ѥå (' . $package . ') 򸫤ĤޤǤ';
    }

    $url = $link->url();
    $url =~ s/show_edit_package/show_edit_release/;

    $self->{'mech'}->get($url);

    if ($self->{'mech'}->content() !~ /\Q@{[CREATE_RELEASE_LABEL]}[0]\E/) {
        die '꡼οڡؤΰư˼Ԥޤ';
    }
}

1;

# Local Variables:
# mode: cperl
# coding: euc-japan-unix
# End:

==> mod_uploader-3.0.8.tgz: mod_uploader-3.0.8/util/WWW/SourceforgeJP.pm <==
package WWW::SourceforgeJP;

use strict;
use vars qw($VERSION);

$VERSION = 0.01;

use WWW::Mechanize;

use constant LIST_RELEASE_LABEL         => '꡼ե롦ꥹ';
use constant LIST_RELEASE_LINK_LABEL    => '꡼';
use constant EDIT_RELEASE_LABEL         => '꡼Խ';
use constant EDIT_RELEASE_LINK_LABEL    => 'ե꡼/ѹ';
use constant CREATE_RELEASE_LABEL       => '꡼ο';

sub new {
    my $class = shift;
    my $project = shift;

    my $member = {
        project => $project,
        mech => WWW::Mechanize->new(),
    };

    $member->{'mech'}->agent_alias('Windows IE 6');

    bless $member, $class;
}

sub login {
    my $self = shift;
    my $user = shift;
    my $pass = shift;

    $self->{'mech'}->get('https://sourceforge.jp/account/login.php');
    $self->{'mech'}->form_number(1);
    $self->{'mech'}->field('form_loginname', $user);
    $self->{'mech'}->field('form_pw', $pass);
    $self->{'mech'}->click();

    if ($self->{'mech'}->content() =~ /\QInvalid\E/) {
        die '˼Ԥޤ';
    }
}

sub create_release {
    my $self = shift;
    my $package = shift;
    my $version = shift;
    my $file_path = shift;
    my $file_name  = (split(/[\/\\]/, $file_path))[-1];
    my @links;

    @links = $self->get_release_links();

    if (grep($_->text() eq $file_name, @links)) {
        die 'Ʊ̾Υ꡼¸ߤޤ';
    }

    $self->_mv_create_release_page($package);

    $self->{'mech'}->form_number(1);
    $self->{'mech'}->field('release_name', $version);
    $self->{'mech'}->field('userfiles[]', $file_path);
    $self->{'mech'}->click();

    @links = $self->get_release_links();

    unless (grep($_->text() eq $file_name, @links)) {
        die '꡼κ˼Ԥޤ';
    }
}

sub get_release_links {
    my $self = shift;
    my @links;

    $self->_mv_list_release_page();

    @links = grep($_->url() =~ m|\Qhttp://prdownloads.\E|,
                  $self->{'mech'}->find_all_links());

    map { $_->[0] }
        sort { $b->[1] <=> $a->[1] }
            map { [$_, ($_->text() =~ /([\d.]+)/)[0]] } @links;
}


sub _mv_list_release_page {
    my $self = shift;
    my $link;

    $self->{'mech'}->get("/projects/@{[$self->{'project'}]}/admin");

    $link = $self->{'mech'}->find_link(text => LIST_RELEASE_LINK_LABEL);
    $self->{'mech'}->get($link->url());

    if ($self->{'mech'}->content() !~ /\Q@{[LIST_RELEASE_LABEL]}[0]\E/) {
        die '꡼ΰڡؤΰư˼Ԥޤ';
    }
}

sub _mv_edit_release_page {
    my $self = shift;
    my $link;

    $self->{'mech'}->get("/projects/@{[$self->{'project'}]}/admin");
    $link = $self->{'mech'}->find_link(text => EDIT_RELEASE_LINK_LABEL);
    $self->{'mech'}->get($link->url());

    if ($self->{'mech'}->content() !~ /\Q@{[EDIT_RELEASE_LABEL]}[0]\E/) {
        die '꡼Խڡؤΰư˼Ԥޤ';
    }
}

sub _mv_create_release_page {
    my $self = shift;
    my $package = shift;
    my $link;
    my $url;

    $self->_mv_edit_release_page();
    $link = $self->{'mech'}->find_link(text => $package);

    if (! defined $link) {
        die 'ѥå (' . $package . ') 򸫤ĤޤǤ';
    }

    $url = $link->url();
    $url =~ s/show_edit_package/show_edit_release/;

    $self->{'mech'}->get($url);

    if ($self->{'mech'}->content() !~ /\Q@{[CREATE_RELEASE_LABEL]}[0]\E/) {
        die '꡼οڡؤΰư˼Ԥޤ';
    }
}

1;

# Local Variables:
# mode: cperl
# coding: euc-japan-unix
# End:
